/***************************************************************************
 *   copyright            : (C) 1999 by Daniel Reith                       *
 *   email                : DanR@gmx.de                                    *
 *                                                                         *
 *   copyright           : (C) 2003 by Hendrik Sattler                     *
 *   mail                : pingos@hendrik-sattler.de                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef L_AUSWERTUNG_H
#define L_AUSWERTUNG_H

#include "lektion.h"
#include <wx/wx.h>

class lauswertung : public wxDialog {
public:
  lauswertung(wxWindow *parent, const wxString& title, Lektion* lektion);
};
#endif
